@@ -56,7 +56,7 @@ from polyaxon.utils.validation import validate_tags
 @click.option(
     "--hub",
     type=str,
-    help="The component hub name containing the polyaxonfile to run.",
+    help="The Component Hub name containing the polyaxonfile to run.",
 )
 @click.option(
     "--name",
@@ -106,7 +106,7 @@ from polyaxon.utils.validation import validate_tags
     "--nocache",
     is_flag=True,
     default=None,
-    help="Check cache before starting this operation.",
+    help="Disable cache check before starting this operation.",
 )
 @click.pass_context
 @clean_outputs
@@ -135,43 +135,43 @@ def run(
     Examples:
 
     \b
-    ```bash
     $ polyaxon run -f file -f file_override ...
-    ```
 
     Upload before running
 
     \b
-    ```bash
     $ polyaxon run -f file -u
-    ```
 
     Run and set description and tags for this run
 
     \b
-    ```bash
     $ polyaxon run -f file -u --description="Description of the current run" --tags="foo, bar, moo"
-    ```
+
     Run and set a unique name for this run
 
     \b
-    ```bash
     polyaxon run --name=foo
-    ```
 
     Run for a specific project
 
     \b
-    ```bash
     $ polyaxon run -p project1 -f file.yaml
-    ```
 
     Run with updated params
 
     \b
-    ```bash
     $ polyaxon run -p project1 -f file.yaml -P param1=234.2 -P param2=relu
-    ```
+
+    If a python file contains a component main, you can run that component
+
+    \b
+    polyaxon run -pm path/to/my-component.py
+
+
+    If a python file contains more than one component, you can specify the component to run
+
+    \b
+    polyaxon run -pm path/to/my-component.py:componentA
     """
     op_spec = check_polyaxonfile(
         polyaxonfile=polyaxonfile,
